=== modified file 'loggerhead/changecache.py'
--- loggerhead/changecache.py	2007-08-30 11:14:53 +0000
+++ loggerhead/changecache.py	2007-09-03 13:58:46 +0000
@@ -225,7 +225,6 @@
 class FileChangeCache(object):
     def __init__(self, history, cache_path):
         self.history = history
-        self.log = history.log
 
         if not os.path.exists(cache_path):
             os.mkdir(cache_path)
@@ -236,24 +235,6 @@
         # different processes.
         self._lock = LockFile(os.path.join(cache_path, 'filechange-lock'))
 
-        self._closed = False
-
-    def _cache(self):
-        return FakeShelf(self._changes_filename)
-
-    @with_lock
-    def close(self):
-        self.log.debug('Closing cache file.')
-        self._closed = True
-
-    @with_lock
-    def closed(self):
-        return self._closed
-
-    @with_lock
-    def flush(self):
-        pass
-
     @with_lock
     def get_file_changes(self, entries):
         out = []

=== added file 'loggerhead/tests/test_filechangecache.py'
--- loggerhead/tests/test_filechangecache.py	1970-01-01 00:00:00 +0000
+++ loggerhead/tests/test_filechangecache.py	2007-09-03 11:16:33 +0000
@@ -0,0 +1,95 @@
+from loggerhead.changecache import FileChangeCache
+
+import random
+import shutil
+import tempfile
+
+
+class MockEntry:
+    def __init__(self, revid):
+        self.revid = revid
+
+
+class MockHistory:
+    def __init__(self):
+        self.fetched_revids = set()
+    def get_file_changes_uncached(self, entries):
+        output = []
+        for entry in entries:
+            self.fetched_revids.add(entry.revid)
+            output.append(entry.revid)
+        return output
+
+
+class TestFileChangeCache(object):
+
+    # there are so i can run it with py.test and take advantage of the
+    # error reporting...
+    def setup_method(self, meth):
+        self.setUp()
+
+    def teardown_method(self, meth):
+        self.tearDown()
+
+    def setUp(self):
+        self.cache_folder = tempfile.mkdtemp()
+
+    def tearDown(self):
+        shutil.rmtree(self.cache_folder)
+
+    def test_empty_cache(self):
+        """An empty cache passes all the revids through to the history object.
+        """
+
+        history = MockHistory()
+        cache = FileChangeCache(history, self.cache_folder)
+
+        revids = ['a', 'b']
+        entries = [MockEntry(revid) for revid in revids]
+
+        result = cache.get_file_changes(entries)
+
+        assert result == revids
+
+        assert history.fetched_revids == set(revids)
+
+    def test_full_cache(self):
+        """A full cache passes none of the revids through to the history
+        object.
+        """
+
+        history = MockHistory()
+        cache = FileChangeCache(history, self.cache_folder)
+
+        revids = ['a', 'b']
+        entries = [MockEntry(revid) for revid in revids]
+
+        # One call to fill the cache
+        cache.get_file_changes(entries)
+        history.fetched_revids.clear()
+
+        result = cache.get_file_changes(entries)
+        assert result == revids
+
+        assert history.fetched_revids == set()
+
+    def test_partial_cache(self):
+        """A partially full cache passes some of the revids through to the
+        history object, and preserves the ordering of the argument list.
+        """
+
+        history = MockHistory()
+        cache = FileChangeCache(history, self.cache_folder)
+
+        revids = [chr(ord('a') + i) for i in range(20)]
+        entries = [MockEntry(revid) for revid in revids]
+
+        some_entries = random.sample(entries, len(entries)/2)
+        cache.get_file_changes(some_entries)
+        history.fetched_revids.clear()
+
+        result = cache.get_file_changes(entries)
+        assert result == revids
+
+        assert history.fetched_revids \
+               == set(revids) - set([e.revid for e in some_entries])

